/* $Id: mpegts.h,v 1.6 2012/08/05 19:11:16 wg Exp $ */

#ifndef MPEGTS_H_
#define MPEGTS_H_

#include <stdio.h>
#include <inttypes.h>

#define TS_PACKET_SIZE 188

/*------------------------------------------------------------------------*/

enum AVMediaType {
    AVMEDIA_TYPE_UNKNOWN = -1,
    AVMEDIA_TYPE_VIDEO,
    AVMEDIA_TYPE_AUDIO,
    AVMEDIA_TYPE_DATA,
    AVMEDIA_TYPE_SUBTITLE,
    AVMEDIA_TYPE_ATTACHMENT,
    AVMEDIA_TYPE_NB
};

enum CodecId {
    CODEC_ID_NONE,
    CODEC_ID_MP3,
    CODEC_ID_AAC,
    CODEC_ID_AAC_LATM, /* LATM syntax */
    CODEC_ID_MPEG2VIDEO,
    CODEC_ID_MPEG4,
    CODEC_ID_H264,
    CODEC_ID_DIRAC,
    CODEC_ID_VC1
};

struct TSContext;
struct utimbuf;

int     mpegts_get_pid(const uint8_t* pkt);
int64_t get_pcr(const uint8_t* pkt);
void    print_pcr(FILE* f, int64_t pcr);
int64_t atopcr(const char* s);

struct TSContext* mpegts_new_context(const char* f);
void              mpegts_delete_context(struct TSContext* ts);

// Return number of packets N read into the buffer.
// If N is least one, the fd will point at the sync byte that
// should follow the last packet read, and mpegts_get_packet_offset()
// will return the offset to the 1st packet read.
int     mpegts_read_packets(struct TSContext* ts,
			    unsigned char* buf, size_t buffer_packets);

// Parse a packet and change section data if necessary.
// Returns non-0 if keyframe_offset was updated.
int     mpegts_parse_packet(struct TSContext* ts,
			    unsigned char* pkt, int64_t pcr);

void	mpegts_compute_best_sid(struct TSContext* ts, const long pid_histo[]);
void	mpegts_print_pmt(const struct TSContext* ts);
// absolute seek, if offset<0 relative to EOF
int64_t mpegts_seek(struct TSContext* ts, int64_t offset);

// The current file offset.
// After a successful read_packets() this will point to the
// start of the next (synced) packet.
int64_t mpegts_get_offset(const struct TSContext* ts);

int64_t mpegts_get_packet_offset(const struct TSContext* ts);
int64_t mpegts_get_keyframe_offset(const struct TSContext* ts);
int     mpegts_get_utime(const struct TSContext* ts, struct utimbuf* ut);

#endif
